aboutsummaryrefslogtreecommitdiff
path: root/install.sh
diff options
context:
space:
mode:
Diffstat (limited to 'install.sh')
-rwxr-xr-xinstall.sh29
1 files changed, 17 insertions, 12 deletions
diff --git a/install.sh b/install.sh
index 8be0c69..de062e0 100755
--- a/install.sh
+++ b/install.sh
@@ -1,29 +1,28 @@
#!/bin/sh
-#yaourt -S qterminal
-##yaourt -S Atom
+# `yolo` is alias to `n yaourt --noconfirm` where `n` is aliased to `notify` which is aliased to `~/.scripts/notify`
+#yolo -S qterminal
+##yolo -S Atom
##apm install atom-material-ui
##apm install atom-material-syntax-dark
##apm install vim-mode-plus
#apm install project-plus
-#yaourt -S fira-code-git
-yaourt -S otf-fira-code
+#yolo -S fira-code-git
+yolo -S otf-fira-code
#wget https://bootstrap.pypa.io/get-pip.py
-#yaourt -S wget
+#yolo -S wget
#sudo python get-pip.py
#sudo pip install i3pystatus
#sudo pip install colour
#sudo pip install netifaces
#sudo pip install basiciw
#yaourt -S py3status
#yaourt -S firefox
#yaourt -S newsbeuter
#yaourt -S mosh
#sudo pacman -S the_silver_searcher
-## TODO: install this: mutt stow
-
-##yaourt -S thunderbird
+##yolo -S thunderbird
#sudo pacman -R clipit
@@ -54,3 +53,9 @@ yaourt -S otf-fira-code
#git clone https://github.com/vundlevim/vundle.vim.git ~/.config/nvim/bundle/Vundle.vim
#sudo pacman -S python-neovim
+
+## Install mutt
+
+# yolo Module::Install # <== required by html-view
+# yolo htmail-view
+# stow mutt
@@ -1,29 +1,28 @@
#sudo pip install netifaces
#sudo pip install basiciw
-#yaourt -S py3status
-#yaourt -S firefox
-#yaourt -S newsbeuter
-#yaourt -S mosh
+#yolo -S py3status
+#yolo -S firefox
+#yolo -S newsbeuter
+#yolo -S mosh
#sudo pacman -S the_silver_searcher